inline std::ostream &nlindent(std::ostream &out)
{
    return out << '\n' << indent;
}
